# `nsidc-iceflow`

```{toctree}
:maxdepth: 2
:hidden:
:caption: content

getting-started.md
altimetry-data-overview.md
notebooks/index.md
contributing.md
API Docs <api/nsidc>
LICENSE
```

```{include} ../README.md

```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
